@@ -118,6 +118,23 @@ impl std::ops::Add<Instruction> for Instruction {
     }
 }
 
+/// From iterator operation for a vector of instructions
+impl std::iter::FromIterator<Instruction> for Option<Instruction> {
+    fn from_iter<I: IntoIterator<Item=Instruction>>(iter: I) -> Self {
+        let mut r = None;
+
+        for elem in iter {
+            if let Some(rd) = &mut r {
+                *rd += elem;
+            } else {
+                r = Some(elem);
+            }
+        }
+
+        r
+    }
+}
+
 /// Mutable addition for instructions
 impl std::ops::AddAssign for Instruction {
     fn add_assign(&mut self, other: Self) {
@@ -238,9 +255,6 @@ impl Instruction {
     /// Creates a table with four columns
     ///
     /// Tables with four columns can be quite tight in 80mm printers, and unthinkable in 58mm ones or smaller. Use with caution!
-    /// ```rust,no_run
-    /// // Tables with quad values should look more like the following.
-    /// ```
     pub fn quad_table<A: Into<String>, B: Into<String>, C: Into<String>, D: Into<String>>(name: A, header: (B, C, D)) -> Instruction {
         Instruction::QuadTable {
             name: name.into(),
